import ctypes
import sys


# Load the Rust library
if sys.platform.startswith("win32"):
    rust_lib = ctypes.CDLL("target/release/passwords_generator.dll")
else:
    rust_lib = ctypes.CDLL("target/release/passwords_generator.so")

# Deklaracja typu zwracanego przez funkcję generate_passwords_with_strength_wrapper
rust_lib.generate_passwords_with_strength_wrapper.restype = ctypes.POINTER(ctypes.POINTER(ctypes.c_char))


# Funkcje API
def generate_passwords_with_strength(passwd_length, num_passwords):
    # Wywołanie funkcji generate_passwords_with_strength_wrapper
    passwords_ptr = rust_lib.generate_passwords_with_strength_wrapper(
        ctypes.c_size_t(passwd_length), ctypes.c_size_t(num_passwords)
    )

    # Odbiór wygenerowanych haseł
    passwords = []
    for i in range(num_passwords):
        password_c_str = ctypes.string_at(passwords_ptr[i]).decode()
        passwords.append(password_c_str)

    # Zwolnienie zaalokowanej pamięci przez Rust
    rust_lib.free_passwords_array(passwords_ptr, num_passwords)
    return passwords


def main():
    passwd_length = int(input("Podaj ilość znaków w haśle: "))
    num_passwords = int(input("Podaj żądaną ilość haseł do wygenerowania: "))
    password = generate_passwords_with_strength(passwd_length, num_passwords)
    print(f"Wygenerowano {num_passwords} haseł, każde o długości {passwd_length}:", "".join([f"\n{i}. {passwd}" for i, passwd in enumerate(password, start=1)]))


if __name__ == "__main__":
    main()
